@@ -23,15 +23,6 @@ struct lo_arg
 	}			u;
 };
 
-#define LO_CREAT					957
-#define LO_OPEN						952
-#define LO_CLOSE					953
-#define LO_READ						954
-#define LO_WRITE					955
-#define LO_LSEEK					956
-#define LO_TELL						958
-#define LO_UNLINK					964
-
 #define INV_WRITE					0x00020000
 #define INV_READ					0x00040000
 
@@ -42,6 +33,5 @@ Int4		odbc_lo_read(ConnectionClass *conn, int fd, char *buf, Int4 len);
 Int4		odbc_lo_write(ConnectionClass *conn, int fd, char *buf, Int4 len);
 Int4		odbc_lo_lseek(ConnectionClass *conn, int fd, int offset, Int4 len);
 Int4		odbc_lo_tell(ConnectionClass *conn, int fd);
-int		odbc_lo_unlink(ConnectionClass *conn, OID lobjId);
 
 #endif
