@@ -1320,6 +1320,7 @@ SC_create_errorinfo(const StatementClass *self)
 		ermsg = msg;
 	}
 	pgerror = ER_Constructor(self->__error_number, ermsg);
+	if (!pgerror) return NULL;
 	if (sqlstate)
 		strcpy(pgerror->sqlstate, sqlstate);
 	else if (conn)
@@ -1505,7 +1506,7 @@ inolog("SC_full_error_copy %p->%p\n", from ,self);
 	else if (!allres)
 		return;
 	pgerror = SC_create_errorinfo(from);
-	if (!pgerror->__error_message[0])
+	if (!pgerror || !pgerror->__error_message[0])
 	{
 		ER_Destructor(pgerror);
 		return;
@@ -1929,10 +1930,10 @@ SC_execute(StatementClass *self)
 		{
 			qi.result_in = NULL;
 			qi.cursor = SC_cursor_name(self);
-			qi.row_size = ci->drivers.fetch_max;
+			qi.fetch_size = qi.row_size = ci->drivers.fetch_max;
 			snprintf(fetch, sizeof(fetch),
 					 "fetch " FORMAT_LEN " in \"%s\"",
-					 qi.row_size, SC_cursor_name(self));
+					 qi.fetch_size, SC_cursor_name(self));
 			qryi = &qi;
 			appendq = fetch;
 		}
@@ -2178,8 +2179,8 @@ inolog("!!! numfield=%d field_type=%u\n", QR_NumResultCols(res), QR_get_field_ty
 			SC_set_fetchcursor(self);
 			qi.result_in = NULL;
 			qi.cursor = SC_cursor_name(self);
-			qi.row_size = ci->drivers.fetch_max;
-			snprintf(fetch, sizeof(fetch), "fetch " FORMAT_LEN " in \"%s\"", qi.row_size, SC_cursor_name(self));
+			qi.cache_size = qi.row_size = ci->drivers.fetch_max;
+			snprintf(fetch, sizeof(fetch), "fetch " FORMAT_LEN " in \"%s\"", qi.fetch_size, SC_cursor_name(self));
 			res = CC_send_query(conn, fetch, &qi, qflag, SC_get_ancestor(self));
 			if (NULL != res)
 				SC_set_Result(self, res);
@@ -2755,6 +2756,11 @@ ParseAndDescribeWithLibpq(StatementClass *stmt, const char *plan_name,
 
 	if (!res)
 		res = QR_Constructor();
+	if (!res)
+	{
+		SC_set_error(stmt, STMT_NO_MEMORY_ERROR, "Couldn't allocate memory for query", func);
+		return NULL;
+	}
 
 	/*
 	 * We need to do Prepare + Describe as two different round-trips to the
