@@ -325,7 +325,6 @@ void SC_set_Result(StatementClass *self, QResultClass *res);
 #define	SC_get_errornumber(a) (a->__error_number)
 #define	SC_set_errornumber(a, n) (a->__error_number = n)
 #define	SC_get_errormsg(a) (a->__error_message)
-#define	SC_get_errormsg(a) (a->__error_message)
 #define	SC_is_prepare_statement(a) (0 != (a->prepare & PREPARE_STATEMENT))
 #define	SC_get_prepare_method(a) (a->prepare & (~PREPARE_STATEMENT))
 
@@ -370,6 +369,17 @@ do { \
 	} \
 	t = tmp; \
 } while (0)
+#define	SC_REALLOC_gexit_with_error(t, tp, s, a, m, r) \
+do { \
+	tp *tmp; \
+	if (tmp = (tp *) realloc(t, s), NULL == tmp) \
+	{ \
+		SC_set_error(a, STMT_NO_MEMORY_ERROR, m, __FUNCTION__); \
+		r; \
+		goto cleanup; \
+	} \
+	t = tmp; \
+} while (0)
 
 /*	options for SC_free_params() */
 #define STMT_FREE_PARAMS_ALL				0
