@@ -13,7 +13,7 @@
  *
  * API functions:	none
  *
- * Comments:		See "notice.txt" for copyright and license information.
+ * Comments:		See "readme.txt" for copyright and license information.
  *-------
  */
 
@@ -36,11 +36,10 @@ set_tuplefield_string(TupleField *tuple_field, const char *string)
 {
 	if (string)
 	{
-		tuple_field->len = strlen(string);
-		tuple_field->value = malloc(strlen(string) + 1);
-		strcpy(tuple_field->value, string);
+		tuple_field->len = (Int4) strlen(string); /* PG restriction */
+		tuple_field->value = strdup(string);
 	}
-	else
+	if (!tuple_field->value)
 		set_tuplefield_null(tuple_field);
 }
 
@@ -52,7 +51,7 @@ set_tuplefield_int2(TupleField *tuple_field, Int2 value)
 
 	sprintf(buffer, "%d", value);
 
-	tuple_field->len = strlen(buffer) + 1;
+	tuple_field->len = (Int4) (strlen(buffer) + 1);
 	/* +1 ... is this correct (better be on the save side-...) */
 	tuple_field->value = strdup(buffer);
 }
@@ -63,9 +62,9 @@ set_tuplefield_int4(TupleField *tuple_field, Int4 value)
 {
 	char		buffer[15];
 
-	sprintf(buffer, "%ld", value);
+	sprintf(buffer, "%d", value);
 
-	tuple_field->len = strlen(buffer) + 1;
+	tuple_field->len = (Int4) (strlen(buffer) + 1);
 	/* +1 ... is this correct (better be on the save side-...) */
 	tuple_field->value = strdup(buffer);
 }
